@@ -1,16 +1,17 @@
 from tempfile import TemporaryFile
 from math import log
 
-def _fd_or_path_or_tempfile(fd, mode='w+', tempfile=True):
+
+def _fd_or_path_or_tempfile(fd, mode='w+b', tempfile=True):
     if fd is None and tempfile:
-        fd = TemporaryFile()
+        fd = TemporaryFile(mode=mode)
 
     if isinstance(fd, basestring):
         fd = open(fd, mode=mode)
-        
+
     return fd
-        
-        
+
+
 def db_to_float(db):
     """
     Converts the input db to a float, which represents the equivalent
@@ -26,9 +27,9 @@ def ratio_to_db(ratio, val2=None):
     to the ratio in power represented by the multiplier passed in.
     """
     ratio = float(ratio)
-    
+
     # accept 2 values and use the ratio of val1 to val2
     if val2 is not None:
         ratio = ratio / val2
-        
-    return 10 * log(ratio, 10)
\ No newline at end of file
+
+    return 10 * log(ratio, 10)
